======
Gentoo
======

Salt can be easily installed on Gentoo via Portage:

.. code-block:: bash

    emerge app-admin/salt

Post-installation tasks
=======================

Now go to the :ref:`Configuring Salt<configuring-salt>` page.
